<?PHP
# ========================================================================== #
#                  IRSR - Invisionix Roaming System Remote                   #
# ========================================================================== #
#                                                                            #
#  Copyright (c) 2003 to this year, by Invisionix Systems.                   #
#     http://www.invisionix.org                                              #
#                                                                            #
#  This file is part of the IRSR.                                            #
#      IRSR is free software; you can redistribute it and/or modify it       #
#  under the terms of the GNU General Public License as published by the     #
#  Free Software Foundation; Latest version.                                 #
#      IRSR is distributed in the hope that it will be useful, but           #
#  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY#
#  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License   #
#  for more details.                                                         #
#      You should have received a copy of the GNU General Public License     #
#  along with IRSR (see IRSR-license.php); if not, write to:                 #
#  Software Foundation, Inc., 59 Temple Pl., Suite 330, Boston, MA 02111-1307#
#            http://www.opensource.org/licenses/gpl-license.php              #
# ========================================================================== #
#                                                                            #


#
# Online/offline private data synchronization functions.
#

$pageExecutionTimeout = 120;			// 2 minutes maximum upload or download time.

function syncOffline($fileUp) {			// Uploading synchronization.
	global $pageExecutionTimeout;

	@ignore_user_abort();
	@set_time_limit($pageExecutionTimeout);
	clearstatcache();			// Make sure the dir's existence info is not cached.

	if (strcmp(basename($fileUp, ".zip"), basename($fileUp)) == 0) {	// Is this a ".gz" file?
		if (!unGZipFile($fileUp)) return false; // Unable to unGZip the GZipped file?
	} else {
		if (!unZipFile($fileUp)) return false;	// Unable to unZip the Zipped file?
	}

	return true;
}


function unGZipFile($gzippedFile) {		// Upload and unGZip a zipped file.
	global $privateDir;

	if (file_exists($privateDir) && is_dir($privateDir)) { // Directory already exists, but shouldn't.
		print "<br>The 'private' directory already exists. It probably";
		print "<br>wasn't removed during the last synchronization !<br>";
		print "<br>Figure out why it's still there, and remove it manually if you wish.<br>";
		return false;
	}

	if (!mkdir($privateDir, 0777)) {	// Unable to create the private directory?
		print "<br>Unable to create the private directory.<br>\n";
		return false;
	}

	echo gzread($gzippedFile, 3);		// Read 3 characters first.
	gzpassthru($gzippedFile);		// Output until end of the file and close it.
	$tmpFname = tempnam("./", "tmp_"); 	// Create temporary transitional file name.
	if (!$fp=fopen($tmpFname, "wb+")) { 	// Unable to open the private transition file?
		print "<br>Unable to create the private uncompressed transition file.<br>\n";
		return false;
	}

	if (!$gzfp=gzopen("$gzippedFile", "rb")) { // Unable to decompress the GZipped file?
		print "<br>Unable to open the GZipped file for decompression.<br>\n";
		fclose($fp); unlink($tmpFname);	// Close and delete the output file.
		return false;
	}

	$decompedText=gzread($gzfp);		// Decompress the GZipped file.
	if(fwrite($fp, $decompedText) === false) {
		print "<br>Unable to write transition file for decompression.<br>\n";
		fclose($fp); unlink($fp); 	// Close and delete the output file.
		if (!gzclose($gzfp)) print "<br>Unable to close the GZipped file properly.<br>\n";
		return false;
	}

	$newFileName = basename($gzippedFile,".gz") . ".txt";	// Create final private file name.
	if (!fclose($fp)) print "<br>Unable to close the transition file properly.<br>\n";
	if (!rename($tmpFname, "{$privateDir}$newFileName")) print "<br>Unable to move the transition file to the private folder.<br>\n";
	if (!gzclose($gzfp)) print "<br>Unable to close the GZipped file.<br>\n";
	if (!unlink("$gzippedFile")) print "<br>Unable to delete the temporary GZipped file.<br>\n";

	return true;
}

function GZipFile($fileName) {			// GZip and download a file to the user's machine.
	global $_sysRootURLdefault;
	global $privateDir;

	$newFileName = str_replace(".txt", ".gz", $fileName);	// Create transition file name.
	$fileDir = "./";
	$relPathSyncoff = "/programs/tools/syncoffline/";	// The Syncoffline directory relative path.
	$fileURL = "{$_sysRootURLdefault}{$relPathSyncoff}{$newFileName}";	// Supply complete URL.
	$fileString="{$fileDir}{$newFileName}";			// combine the path and file
	$fileNmStr="{$fileDir}{$fileName}";			// combine the path and file

	if(!is_file("{$privateDir}$fileName")) {	// Is the download file in the private folder?
		print "<br>The download file could not be found !!<br>";
		return false;
	} else {
		if (!rename("{$privateDir}$fileName", "$fileNmStr")) print "<br>Unable to move the file out of the private folder.<br>\n";
		if (($fpS = fopen($fileNmStr, "rb")) !== false) { // Open the file to be read.
			if (($outputStr=fread($fpS, filesize($fileNmStr))) === false) print "<br>Unable to input the file's contents.<br>\n";	// Get the file's contents.
			fclose($fpS);
		} else { print "<br>Unable to open file to be read.<br>\n"; }
		if ($zp=gzopen($fileString,"wb9")) {	// Open file for writing with maximum compression.
			gzwrite($zp, $outputStr);	// Write string to file.
			gzclose($zp);			// Close the GZipped file.
			if (!unlink($fileNmStr)) print "<br>Unable to delete the temporary transition file.<br>\n";
		} else { return false; }		// Unable to open the output file.
		if (!rmdir($privateDir)) print "<br>Unable to delete the private folder.<br>\n";
		print "<script>location.href=\"downloader.php?fileString=$fileString\";</script>\n";
//ir		print "<script>location.href=\"$fileURL\";</script>\n";
//ir		print "<script>location.href=\"$fileString\";</script>\n";
	}

	return true;
}

function unZipFile($zippedFile) {		// Unzip a zipped file.
	global $privateDir;

	if (function_exists("zip_open") == false) {
		print "<br>Information: ZIP capability does not exist on this server!<br>\n";
		return false;
	}

	if ($zip=zip_open($zippedFile)) {
		return false;			// Problem while opening the zipped file.
	} else {				// Zipped file was opened ok.
		while ($zip_entry = zip_read($zip)) {	// For all entries in the zipped file.
			$file = basename(zip_entry_name($zip_entry));
			$fp = fopen($privateDir.basename($file), "w+");	// Open the output file.
       
			if (zip_entry_open($zip, $zip_entry, "rb")) {	// Open an entry in the zipped input file.
				$buf = zip_entry_read($zip_entry, zip_entry_filesize($zip_entry));
				zip_entry_close($zip_entry);
			} else {
				return false;
			}
       
			fwrite($fp, $buf);
			fclose($fp);
       
			echo "The file ".$file." was extracted to dir ".$privateDir."\n<br>";
		}
		zip_close($zip);
	}

	return true;
}

function ZipDir() {				// Zip the private directory and its contents.
	global $privateDir;

	$resultArray = ftp_zipdirectory("email", "", $privateDir, $selectedEntries, "/", 0);

	return true;
}

?> 