<?PHP
# ========================================================================== #
#                  IRSR - Invisionix Roaming System Remote                   #
# ========================================================================== #
#                                                                            #
#  Copyright (c) 2003 to this year, by Invisionix Systems.                   #
#     http://www.invisionix.org                                              #
#                                                                            #
#  This file is part of the IRSR.                                            #
#      IRSR is free software; you can redistribute it and/or modify it       #
#  under the terms of the GNU General Public License as published by the     #
#  Free Software Foundation; Latest version.                                 #
#      IRSR is distributed in the hope that it will be useful, but           #
#  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY#
#  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License   #
#  for more details.                                                         #
#      You should have received a copy of the GNU General Public License     #
#  along with IRSR (see IRSR-license.php); if not, write to:                 #
#  Software Foundation, Inc., 59 Temple Pl., Suite 330, Boston, MA 02111-1307#
#            http://www.opensource.org/licenses/gpl-license.php              #
# ========================================================================== #
# pseudo-cron v1.2.2                                                         #
# (c) 2003,2004 Kai Blankenhorn                                              #
# www.bitfolge.de/pseudocron                                                 #
# kaib@bitfolge.de                                                           #
# ========================================================================== #
#                                                                            #

// **************************************
//		config section		*
// **************************************

// || PLEASE NOTE:
// || all paths used here and in cron scripts 
// || must be absolute or relative to pseudo-cron.inc.php!
// ||
// || To easily use absolute paths, have a look at how the
// || crontab location is defined below.


// the file that contains the job descriptions
// for a description of the format, see the site
// http://www.unixgeeks.org/security/newbie/unix/cron-1.html
// and http://www.bitfolge.de/pseudocron
$cronTab = dirname(__FILE__)."/cronjobs/crontab.txt";

// the directory where the script can store information
// on completed jobs and its log file
// include trailing slash
$writeDir = dirname(__FILE__)."/cronjobs/";

// control logging, 1=use log file, 0=don't use log file
$useLog = 1;

// Where to send cron results.
$sendLogToEmail = "id@invisionix.org";

// turn on / off debugging output
// DO NOT use this on live servers!
$debug = false;

// **************************************
//	don't change anything here	
// **************************************

define("PC_MINUTE",	1);
define("PC_HOUR",	2);
define("PC_DOM",	3);
define("PC_MONTH",	4);
define("PC_DOW",	5);
define("PC_CMD",	7);
define("PC_COMMENT",	8);
define("PC_CRONLINE", 20);

$resultsSummary = "";

function logMessage($msg) {
	GLOBAL $writeDir, $useLog, $debug, $resultsSummary;
	if ($msg[strlen($msg)-1]!="\n") {
		$msg.="\n";
	}
	if ($debug) echo $msg;
	$resultsSummary.= $msg;
	if ($useLog==1) {
		$logfile = $writeDir."pseudo-cron.log";
		$file = fopen($logfile,"a");
		fputs($file,date("r",time())."  ".$msg);
		fclose($file);
	}
}

function lTrimZeros($number) {
	GLOBAL $debug;
	while ($number[0]=='0') {
		$number = substr($number,1);
	}
	return $number;
}

function parseElement($element, &$targetArray, $numberOfElements) {
	GLOBAL $debug;
	$subelements = explode(",",$element);
	for ($i=0;$i<$numberOfElements;$i++) {
		$targetArray[$i] = $subelements[0]=="*";
	}
	
	for ($i=0;$i<count($subelements);$i++) {
		if (preg_match("~^(\\*|([0-9]{1,2})(-([0-9]{1,2}))?)(/([0-9]{1,2}))?$~",$subelements[$i],$matches)) {
			if ($matches[1]=="*") {
				$matches[2] = 0;		// from
				$matches[4] = $numberOfElements;		//to
			} elseif ($matches[4]=="") {
				$matches[4] = $matches[2];
			}
			if ($matches[5][0]!="/") {
				$matches[6] = 1;		// step
			}
			for ($j=lTrimZeros($matches[2]);$j<=lTrimZeros($matches[4]);$j+=lTrimZeros($matches[6])) {
				$targetArray[$j] = TRUE;
			}
		}
	}
}

function decDate(&$dateArr, $amount, $unit) {
	GLOBAL $debug;
	if ($debug) echo sprintf("Decreasing from %02d.%02d. %02d:%02d by %d %6s ",$dateArr[mday],$dateArr[mon],$dateArr[hours],$dateArr[minutes],$amount,$unit);
	if ($unit=="mday") {
		$dateArr["hours"] = 23;
		$dateArr["minutes"] = 59;
		$dateArr["seconds"] = 59;
		$dateArr["mday"] -= $amount;
		$dateArr["wday"] -= $amount % 7;
		if ($dateArr["wday"]<0) {
			$dateArr["wday"]+=7;
		}
		if ($dateArr["mday"]<1) {
			$dateArr["mon"]--;
			switch ($dateArr["mon"]) {
				case 0:
					$dateArr["mon"] = 12;
					$dateArr["year"]--;
					// fall through
				case 1:
				case 3:
				case 5:
				case 7:
				case 8:
				case 10:
				case 12:
					$dateArr["mday"] = 31;
					break;
				case 4:
				case 6:
				case 9:
				case 11:
					$dateArr["mday"] = 30;
					break;
				case 2:
					$dateArr["mday"] = 28;
					break;
			}
		}
	} elseif ($unit=="hour") {
		if ($dateArr["hours"]==0) {
			decDate($dateArr, 1, "mday");
		} else {
			$dateArr["minutes"] = 59;
			$dateArr["seconds"] = 59;
			$dateArr["hours"]--;
		}
	} elseif ($unit=="minute") {
		if ($dateArr["minutes"]==0) {
			decDate($dateArr, 1, "hour");
		} else {
			$dateArr["seconds"] = 59;
			$dateArr["minutes"]--;
		}
	}
	if ($debug) echo sprintf("to %02d.%02d. %02d:%02d\n",$dateArr[mday],$dateArr[mon],$dateArr[hours],$dateArr[minutes]);
}

function getLastScheduledRunTime($job) {
	GLOBAL $debug;
	$dateArr = getdate();
	$minutesBack = 0;
	while (
		$minutesBack<525600 AND 
		(!$job[PC_MINUTE][$dateArr["minutes"]] OR 
		!$job[PC_HOUR][$dateArr["hours"]] OR 
		(!$job[PC_DOM][$dateArr["mday"]] OR !$job[PC_DOW][$dateArr["wday"]]) OR
		!$job[PC_MONTH][$dateArr["mon"]])
	) {
		if (!$job[PC_DOM][$dateArr["mday"]] OR !$job[PC_DOW][$dateArr["wday"]]) {
			decDate($dateArr,1,"mday");
			$minutesBack+=1440;
			continue;
		}
		if (!$job[PC_HOUR][$dateArr["hours"]]) {
			decDate($dateArr,1,"hour");
			$minutesBack+=60;
			continue;
		}
		if (!$job[PC_MINUTE][$dateArr["minutes"]]) {
			decDate($dateArr,1,"minute");
			$minutesBack++;
			continue;
		}
	}

	if ($debug) print_r($dateArr);
	
	return mktime($dateArr["hours"],$dateArr["minutes"],0,$dateArr["mon"],$dateArr["mday"],$dateArr["year"]);
}

function getJobFileName($jobname) {
	GLOBAL $writeDir;
	GLOBAL $debug;
	$jobfile = $writeDir.urlencode($jobname).".job";
	return $jobfile;
}

function getLastActialRunTime($jobname) {
	GLOBAL $debug;
	$jobfile = getJobFileName($jobname);
	if (file_exists($jobfile)) {
		$file = fopen($jobfile,"r");
		$lastRun = fgets($file,100);
		fclose($file);
		if (is_numeric($lastRun)) {
			return $lastRun;
		}
	}
	return 0;
}

function markLastRun($jobname, $lastRun) {
	GLOBAL $debug;
	$jobfile = getJobFileName($jobname);
	$file = fopen($jobfile,"w");
	fputs($file,$lastRun);
	fclose($file);
}

function runJob($job) {
	GLOBAL $debug, $sendLogToEmail, $resultsSummary;
	$resultsSummary = "";
	$extjob = Array();
	$jobfile = getJobFileName($job[PC_CMD]);
	parseElement($job[PC_MINUTE], $extjob[PC_MINUTE], 60);
	parseElement($job[PC_HOUR], $extjob[PC_HOUR], 24);
	parseElement($job[PC_DOM], $extjob[PC_DOM], 31);
	parseElement($job[PC_MONTH], $extjob[PC_MONTH], 12);
	parseElement($job[PC_DOW], $extjob[PC_DOW], 7);
	
	$lastActual = getLastActialRunTime($job[PC_CMD]);
	$lastScheduled = getLastScheduledRunTime($extjob);
	
	if ($lastScheduled>$lastActual) {
		logMessage("Running 	".$job[PC_CRONLINE]);
		logMessage("  Last run:       ".date("r",$lastActual));
		logMessage("  Last scheduled: ".date("r",$lastScheduled));
		markLastRun($job[PC_CMD], $lastScheduled);
		if ($debug) {
			include(dirname(__FILE__)."/".$job[PC_CMD]);		// display errors only when debugging
		} else {
			@include($job[PC_CMD]);		// any error messages are supressed
		}
		logMessage("Completed	".$job[PC_CRONLINE]);
		if ($sendLogToEmail!="") {
			mail($sendLogToEmail, "[cron] ".$job[PC_COMMENT], $resultsSummary);
		}
		return true;
	} else {
		if ($debug) {
			logMessage("Skipping 	".$job[PC_CRONLINE]);
			logMessage("  Last run:       ".date("r",$lastActual));
			logMessage("  Last scheduled: ".date("r",$lastScheduled));
			logMessage("Completed	".$job[PC_CRONLINE]);
		}
		return false;
	}
}

function parseCronFile($cronTabFile) {
	GLOBAL $debug;
	$file = file($cronTabFile);
	$job = Array();
	$jobs = Array();
	for ($i=0;$i<count($file);$i++) {
		if ($file[$i][0]!='#') {
//			old regex, without dow abbreviations:
//			if (preg_match("~^([-0-9,/*]+)\\s+([-0-9,/*]+)\\s+([-0-9,/*]+)\\s+([-0-9,/*]+)\\s+([-0-7,/*]+|Sun|Mon|Tue|Wen|Thu|Fri|Sat)\\s+([^#]*)(#.*)?$~i",$file[$i],$job)) {
			if (preg_match("~^([-0-9,/*]+)\\s+([-0-9,/*]+)\\s+([-0-9,/*]+)\\s+([-0-9,/*]+)\\s+([-0-7,/*]+|(-|/|Sun|Mon|Tue|Wed|Thu|Fri|Sat)+)\\s+([^#]*)\\s*(#.*)?$~i",$file[$i],$job)) {
				$jobNumber = count($jobs);
				$jobs[$jobNumber] = $job;
				if ($jobs[$jobNumber][PC_DOW][0]!='*' AND !is_numeric($jobs[$jobNumber][PC_DOW])) {
					$jobs[$jobNumber][PC_DOW] = str_replace(
						Array("Sun","Mon","Tue","Wed","Thu","Fri","Sat"),
						Array(0,1,2,3,4,5,6),
						$jobs[$jobNumber][PC_DOW]);
				}
				$jobs[$jobNumber][PC_CMD] = trim($job[PC_CMD]);
				$jobs[$jobNumber][PC_COMMENT] = trim(substr($job[PC_COMMENT],1));
				$jobs[$jobNumber][PC_CRONLINE] = $file[$i];
			}
		}
	}
	if ($debug) var_dump($jobs);
	return $jobs;
}

if ($debug) echo "<pre>";
$jobs = parseCronFile($cronTab);
for ($i=0;$i<count($jobs);$i++) {
	runJob($jobs[$i]);
}
if ($debug) echo "</pre>";

?>
